==> go.php?file=RaidAchievement1.067.zip: RaidAchievement/Localization/localization-zhTW.lua <==
﻿if GetLocale() == "zhTW" then


function psealocale()


pseachatlist1				= "團隊"
pseachatlist2				= "團隊警告"
pseachatlist3				= "幹部"
pseachatlist4				= "小隊"
pseachatlist5				= "公會"
pseachatlist6				= "說"
pseachatlist7				= "大喊"
pseachatlist8				= "使用者"
pseaaddonmy				= "插件"
pseaaddonon2				= "開啟"
pseaaddonoff				= "關閉"
pseamoduleload				= "載入模組:"
pseamodulenotload			= "載入模組時發生錯誤:"
pseaaddonon				= "啟用插件"
pseaaddonok				= "確定"
pseatreb2				= "完成成就需求! 現在將首領擊殺!"
pseatreb4				= "失敗!"
ranewversfound				= "|cff00ff00注意!|r 在小隊或公會中找到 |cff00ff00'RaidAchievement'|r 插件的新版本, 建議從 curse.com 或 wowinterface.com 取得更新"
pseapartfailedloc			= "部分失敗!"


psealeftmenu1				= "插件"
psealeftmenu3				= "納克薩瑪斯"
psealeftmenu31				= "納克薩瑪斯 + 其他巫妖王團隊"
psealeftmenu4				= "巫妖王之怒英雄"
psealeftmenu5				= "奧杜亞"
psealeftmenu6				= "冰冠城塞"
pseareports				= "- 在此頻道中公布警告"
PSFeaserver				= "ru-Azuregos"
pseauinomodule1				= "    錯誤! 未安裝模組!"
pseauinomodule2				= "錯誤! 未安裝該模組!"
pseauierror				= "    錯誤!"
pseauierroraddonoff			= "錯誤! 插件已關閉 - this module is not loaded!"
pseapsaddonanet				= "錯誤! 未安裝PhoenixStyle插件"
pseapsaddonanet2			= "你可以在 curse.com 或 wowinterface.com 下載此插件"
pseaenableall				= "全部關閉"
pseadisableall				= "全部開啟"
pseachangeall				= "反向選擇"
pseawebsite				= " "
pseashownames				= "顯示成就失敗的原因(名字或其他)"
pseashowveren				= "顯示更新通知"
psealeftmenu11				= "失敗後追蹤"
pseamanyachtitle			= "     失敗後繼續追蹤成就"
ramanyachtitinfo			= "當成就失敗時，當前的戰鬥中將會停止繼續追蹤。這個模組重啟這個功能，在'失敗訊息'出現後的 "
ramanyachtitinfo2			= "後繼續追蹤。下面可設定戰鬥中你想重啟幾次追蹤，並按下'開始'模組。這個模組會在登出後自動關閉。"
psbuttonon				= "開始"
psbuttonoff				= "停止"
psmoduletxton				= "模組開啟"
psmoduletxtoff				= "模組關閉"
rasec					= "秒."
ramanyachtitinfoq			= "戰鬥中將會重啟 "
ramanyachtitinfoq2			= "次追蹤。下面可修改次數："
ramodulnotblock				= "追蹤將不會停止"
psoldvertxt				= "(舊版本)"
raminibuttset				= "顯示小地圖按鈕"

nxratitle				= "    納克薩瑪斯 + 其他巫妖王團隊"
nxraonyxiab				= "奧妮克希亞"
nxraonyemote				= "takes in a deep breath"
icravalitriayell1			= "我打開了一道傳送門通往夢境。你們的救贖就在其中，英雄們……"
icravalitriayell2			= "我重生了!伊瑟拉賦予我讓那些邪惡生物安眠的力量!"
icratitle				= "    冰冠城塞"
raiccof					= "的"
raiccused				= "使用"
pseaulduarkolf1 = "小怪已被擊殺!" 
pseaulduarkolf2 = "成就將因首領被擊殺而無法達成!" 
pseamimifailloc1 = "炸彈機器人!" 
pseamimifailloc2 = "火箭攻擊!" 
pseamimifailloc3 = "環罩地雷!" 
pseamimifailloc5 = "部分失敗!" 
pseatrebulda2 = "殺掉最後一個小怪就可以殺了首領!"
pseaulduartitle = "奧杜亞" 
whrabrann				= "布萊恩·銅鬚"
whrabrannemo				= "you want to play hardball"
whrabrannemo2				= "safes deactivated. Beginning memory purge and"
whragundemo				= "gonna spill your guts"
whraaddkilled1				= "小怪已被擊殺!"
whraaddkilled2				= "成就將因首領被擊殺而無法達成!"



end


end

==> go.php?file=RaidAchievement1.073.zip: RaidAchievement/Localization/localization-zhTW.lua <==
﻿if GetLocale() == "zhTW" then


function psealocale()


pseachatlist1				= "團隊"
pseachatlist2				= "團隊警告"
pseachatlist3				= "幹部"
pseachatlist4				= "小隊"
pseachatlist5				= "公會"
pseachatlist6				= "說"
pseachatlist7				= "大喊"
pseachatlist8				= "使用者"
pseaaddonmy				= "插件"
pseaaddonon2				= "開啟"
pseaaddonoff				= "關閉"
pseamoduleload				= "載入模組:"
pseamodulenotload			= "載入模組時發生錯誤:"
pseaaddonon				= "啟用插件"
pseaaddonok				= "確定"
pseatreb2				= "完成成就需求! 現在將首領擊殺!"
pseatreb4				= "失敗!"
ranewversfound				= "|cff00ff00注意!|r 在小隊或公會中找到 |cff00ff00'RaidAchievement'|r 插件的新版本, 建議從 www.ps-addon.com 取得更新"
pseapartfailedloc			= "部分失敗!"


psealeftmenu1				= "插件"
psealeftmenu3				= "納克薩瑪斯"
psealeftmenu31				= "納克薩瑪斯 + 其他巫妖王團隊"
psealeftmenu4				= "巫妖王之怒英雄"
psealeftmenu5				= "奧杜亞"
psealeftmenu6				= "冰冠城塞"
pseareports				= "- 在此頻道中公布警告"
PSFeaserver				= "ru-Azuregos"
pseauinomodule1				= "    錯誤! 未安裝模組!"
pseauinomodule2				= "錯誤! 未安裝該模組!"
pseauierror				= "    錯誤!"
pseauierroraddonoff			= "錯誤! 插件已關閉 - this module is not loaded!"
pseapsaddonanet				= "錯誤! 未安裝PhoenixStyle插件"
pseapsaddonanet2			= "你可以在 www.ps-addon.com 下載此插件"
pseaenableall				= "全部關閉"
pseadisableall				= "全部開啟"
pseachangeall				= "反向選擇"
pseashownames				= "顯示成就失敗的原因(名字或其他)"
pseashowveren				= "顯示更新通知"
psealeftmenu11				= "失敗後追蹤"
pseamanyachtitle			= "     失敗後繼續追蹤成就"
ramanyachtitinfo			= "當成就失敗時，當前的戰鬥中將會停止繼續追蹤。這個模組重啟這個功能，在'失敗訊息'出現後的 "
ramanyachtitinfo2			= "後繼續追蹤。下面可設定戰鬥中你想重啟幾次追蹤，並按下'開始'模組。這個模組會在登出後自動關閉。"
psbuttonon				= "開始"
psbuttonoff				= "停止"
psmoduletxton				= "模組開啟"
psmoduletxtoff				= "模組關閉"
rasec					= "秒."
ramanyachtitinfoq			= "戰鬥中將會重啟 "
ramanyachtitinfoq2			= "次追蹤。下面可修改次數："
ramodulnotblock				= "追蹤將不會停止"
psoldvertxt				= "(舊版本)"
raminibuttset				= "顯示小地圖按鈕"

nxratitle				= "    納克薩瑪斯 + 其他巫妖王團隊"
nxraonyxiab				= "奧妮克希亞"
nxraonyemote				= "takes in a deep breath"
icravalitriayell1			= "我打開了一道傳送門通往夢境。你們的救贖就在其中，英雄們……"
icravalitriayell2			= "我重生了!伊瑟拉賦予我讓那些邪惡生物安眠的力量!"
icratitle				= "    冰冠城塞"
raiccof					= "的"
raiccused				= "使用"
pseaulduarkolf1 = "小怪已被擊殺!" 
pseaulduarkolf2 = "成就將因首領被擊殺而無法達成!" 
pseamimifailloc1 = "炸彈機器人!" 
pseamimifailloc2 = "火箭攻擊!" 
pseamimifailloc3 = "環罩地雷!" 
pseamimifailloc5 = "部分失敗!" 
pseatrebulda2 = "殺掉最後一個小怪就可以殺了首領!"
pseaulduartitle = "奧杜亞" 
whrabrann				= "布萊恩·銅鬚"
whrabrannemo				= "you want to play hardball"
whrabrannemo2				= "safes deactivated. Beginning memory purge and"
whragundemo				= "gonna spill your guts"
whraaddkilled1				= "小怪已被擊殺!"
whraaddkilled2				= "成就將因首領被擊殺而無法達成!"



end


end
